====
miar
====


.. image:: https://img.shields.io/pypi/v/miar.svg
        :target: https://pypi.python.org/pypi/miar

.. image:: https://readthedocs.org/projects/miar/badge/?version=latest
        :target: https://miar.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




A Python project for interestingness measures of association rules


* Free software: MIT license
* Documentation: https://miar.readthedocs.io.


Features
--------

This package provides over 50 individual interestingness measures for association rules.
They can be imported directly individually or through a dictionary "clm_4ft_int_functions"

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
